/****** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * 
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is XpcomViewer code.
 * 
 * The Initial Developer of the Original Code is NeutronStar, s.r.o.
 * Portions created by NeutronStar, s.r.o. are Copyright (C) 2005 
 * NeutronStar, s.r.o.. All Rights Reserved.
 * 
 * Contributor(s):
 *    Ondrej Donek, <ondrejd@gmail.com>, original author
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the LGPL or the GPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 ****** END LICENSE BLOCK *****/


/**
 * General pane object
 */
var gXPrefWin = 
{

    /**
     * Getters for pointers to UI elements.
     */
    // paneGeneral
	get _paneGeneral () { return document.getElementById ("paneGeneral"); },
	get mUseMenuIcons () { return document.getElementById ("useMenuIcons"); },
	get mShowToolbarAfterStartup () { return document.getElementById ("showToolbarAfterStartup"); },
	get mShowConfirmWhenClosing () { return document.getElementById ("showConfirmWhenClosing"); },
	get mUseAdditionalCSSRules () { return document.getElementById ("useAdditionalCSSRules"); },
	get mUseTreeIcons () { return document.getElementById ("useTreeIcons"); },
    // paneSaveOptions
	get _paneSaveOptions () { return document.getElementById ("paneSaveOptions"); },
	get mUseSaveFile () { return document.getElementById ("useSaveFile"); },
	get mSaveFilter () { return document.getElementById ("saveFilter"); },
	get mSaveLxr () { return document.getElementById ("saveViewedLXRPages"); },
	get mDeleteFileBut () { return document.getElementById ("deleteFile-button"); },
	get mRestoreFileBut () { return document.getElementById ("restoreFile-button"); },
	
	
    /** 
     * Getter for XpcomViewer installation folder in user profile directory.
     * 
     * @return  nsIFile
     */
    get _xpcomViewerProfDir () 
    {
        var file = Components.classes["@mozilla.org/file/directory_service;1"].
            getService(Components.interfaces.nsIProperties).
            get("ProfD", Components.interfaces.nsIFile);
		file.append ("extensions");
		file.append ("{85CBA252-45E8-4e00-AF4D-E7EE9D462A9B}");
		
		return file
    },
	
	
	
	///////////////////////////////////////////
	// global prefswin methods
	
	
	/**
	 * On pane load
	 */
	onLoad : function ()
	{
		window.focus ();
		
		if (!this.fileToDelete ())
		    this.mDeleteFileBut.setAttribute ("disabled", true);
		
		if (!this.fileToRestore ())
		    this.mRestoreFileBut.setAttribute ("disabled", true);
	},
	
	
	
	///////////////////////////////////////////
	// paneGeneral specific methods
	
	
	/**
	 * Fired when user change value of useAdditionalCSSRules preference.
	 */
	onUseAdditionalCSSRulesChange : function ()
	{
	   if (this.mUseAdditionalCSSRules.checked)
	       if (this.mUseTreeIcons.hasAttribute ("disabled"))
	           this.mUseTreeIcons.removeAttribute ("disabled");
	   else 
	       this.mUseTreeIcons.setAttribute ("disabled", true);
	},
	
	
	
	///////////////////////////////////////////
	// paneSaveOptions specific methods
	
		
	/**
	 * Fired when user changed value of useSaveFile preference.
	 */
	onUseSaveFileChange : function ()
	{
	    if (this.mSaveNothing.checked)
	    {
	        // enable all other prefs.
	        if (this.mSaveFilter.hasAttribute ("disabled"))
	           this.mSaveFilter.removeAttribute ("disabled");
	        if (this.mSaveLxr.hasAttribute ("disabled"))
	           this.mSaveLxr.removeAttribute ("disabled");
	    }
	    else
	    {
	        // disable all other prefs
	        this.mSaveFilter.setAttribute ("disabled", true);
	        this.mSaveLxr.setAttribute ("disabled", true);
	    }
	},
	
	
	/**
	 * Delete saved file with xpcom datasource and user 
	 * notes and bookmarks.
	 */
	deleteSaveFile : function ()
	{
        var file = this._xpcomViewerProfDir;
		file.append ("xpcom.rdf");
		
		if (file.exists ())
            file.moveTo (null, "xpcom-backup.rdf");
    },
	
	
	/**
	 * Check if there is any stored datasource file to delete.
	 */
	fileToDelete : function ()
	{
        var file = this._xpcomViewerProfDir;
		file.append ("xpcom.rdf");
		
		return file.exists ();
	},
	
	
	/**
	 * Restore the last deleted file. (This backup file is overwritten 
	 * everytime user choose deleteSaveFile command so only one-step 
	 * backup is possible.
	 */
	restoreLastDeletedFile : function ()
	{
        var file = this._xpcomViewerProfDir;
		file.append ("xpcom-backup.rdf");
		
		if (file.exists ())
            file.moveTo (null, "xpcom.rdf");
	},
	
	
	/**
	 * Check if there is any deleted datasource file to restore.
	 */
	fileToRestore : function ()
	{
        var file = this._xpcomViewerProfDir;
		file.append ("xpcom-backup.rdf");
		
		return file.exists ();
	}
	
};

